==> hgu95av2_1.8.4.tar.gz: hgu95av2/man/hgu95av2PATH.Rd <==
\name{hgu95av2PATH}
\alias{hgu95av2PATH}
\title{Mappings between probe identifiers and KEGG pathway identifiers}
\description{
  KEGG (Kyoto Encyclopedia of Genes and Genomes) maintains pathway data
  for various organisms. hgu95av2PATH maps probe identifiers to the
  identifiers used by KEGG for pathways in which the genes represented
  by the probe identifiers are involved
}
\details{
  Each KEGG pathway has a name and id. Pathway name for a given pathway
  id can be obtained using the KEGG data package that can either be
  built using AnnBuilder or downloaded from Bioconductor
  \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  url{http://www.genome.ad.jp/kegg/pathway.html} by using pathway ids as
  keys.   

  Mappings were based on data provided by:

  KEGG:\url{http://gopher5/compbio/annotationSourceData/kegg/pathways}. Built: Release 34.0 (April 2005)

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue May 17 16:05:54 2005

  Package built Tue May 17 16:16:13 2005
}
\references{
  \url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hgu95av2PATH)
    # Remove probe ids that do not map to any pathway id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The pathway ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}
\keyword{datasets}

==> hgu95av2_1.10.0.tar.gz: hgu95av2/man/hgu95av2PATH.Rd <==
\name{hgu95av2PATH}
\alias{hgu95av2PATH}
\title{Mappings between probe identifiers and KEGG pathway identifiers}
\description{
  KEGG (Kyoto Encyclopedia of Genes and Genomes) maintains pathway data
  for various organisms. hgu95av2PATH maps probe identifiers to the
  identifiers used by KEGG for pathways in which the genes represented
  by the probe identifiers are involved
}
\details{
  Each KEGG pathway has a name and id. Pathway name for a given pathway
  id can be obtained using the KEGG data package that can either be
  built using AnnBuilder or downloaded from Bioconductor
  \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  url{http://www.genome.ad.jp/kegg/pathway.html} by using pathway ids as
  keys.   

  Mappings were based on data provided by:

  KEGG:\url{http://gopher5/compbio/annotationSourceData/kegg/pathways}. Built: Release 36.0, October 1, 2005

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 21:15:59 2005

  Package built Tue Oct  4 21:31:35 2005
}
\references{
  \url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hgu95av2PATH)
    # Remove probe ids that do not map to any pathway id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The pathway ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}
\keyword{datasets}
